"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkForUpdate = checkForUpdate;
/*!
 * I Message Queue Command Line Interface
 *
 * I'm Queue Software Project
 * Copyright (C) 2025  imqueue.com <support@imqueue.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * If you want to use this code in a closed source (commercial) project, you can
 * purchase a proprietary commercial license. Please contact us at
 * <support@imqueue.com> to get commercial licensing options.
 */
const child_process_1 = require("child_process");
const inquirer_1 = require("inquirer");
const pkg = require('../package.json');
// istanbul ignore next
/**
 * Performs check if local version is latest
 */
async function checkForUpdate() {
    try {
        const remoteVersion = (0, child_process_1.execSync)(`npm show ${pkg.name} version`)
            .toString('utf8').trim();
        const localVersion = pkg.version.trim();
        if (remoteVersion !== localVersion) {
            const answer = await inquirer_1.default.prompt([{
                    type: 'confirm',
                    name: 'update',
                    message: `New version ${remoteVersion} of ${pkg.name} available. Would you like to update?`,
                    default: true,
                }]);
            if (answer.update) {
                update();
            }
        }
    }
    catch (err) {
        /* ignore */
    }
}
// istanbul ignore next
/**
 * Executes update command for this package
 */
function update() {
    try {
        console.log('Updating, please, wait...');
        (0, child_process_1.execSync)(`npm i -g ${pkg.name}`);
        console.log('Update success, please, re-run your command again.');
        process.exit(0);
    }
    catch (err) {
        console.error(`UPDATE ERROR:`, err);
    }
}
//# sourceMappingURL=autoupdate.js.map