"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.printError = printError;
/*!
 * IMQ-CLI library: error
 *
 * I'm Queue Software Project
 * Copyright (C) 2025  imqueue.com <support@imqueue.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * If you want to use this code in a closed source (commercial) project, you can
 * purchase a proprietary commercial license. Please contact us at
 * <support@imqueue.com> to get commercial licensing options.
 */
const chalk_1 = require("chalk");
// that is just a printing function, no need to do specific tests
// istanbul ignore next
/**
 * Prints error message to standard error output
 *
 * @param {Error} err - error to display message from
 * @param {boolean} [withStackTrace] - if true will printError error stack
 */
function printError(err, withStackTrace = false) {
    let message = err.message;
    try {
        let obj = JSON.parse(message);
        if (obj.message && obj.errors) {
            message = `${obj.message}: ${obj.errors.map((err) => err.message).join('\n')}`;
        }
    }
    catch (err) { /* ignore */ }
    process.stderr.write(chalk_1.default.bold.red(message) + '\n');
    if (withStackTrace && err.stack) {
        process.stderr.write(chalk_1.default.cyan(err.stack) + '\n');
    }
}
//# sourceMappingURL=error.js.map